@@ -35,6 +35,7 @@
 #  ifndef EINPROGRESS
 #    define EINPROGRESS WSAEINPROGRESS
 #  endif
+#  include "w32lib.h"
 #else
 #  if HAVE_SYS_WAIT_H
 #    include <sys/wait.h>
@@ -62,7 +63,7 @@
 #include "socket.h"
 #include "utils.h"
 #include "log.h"
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 #  include "ssl.h"
 #endif
 
@@ -231,6 +232,11 @@ void refresh_resolvers(void)
 #endif /*G_OS_UNIX*/
 }
 
+#ifdef G_OS_WIN32
+#define SOCKET_IS_VALID(s)      ((s) != INVALID_SOCKET)
+#else
+#define SOCKET_IS_VALID(s) 	TRUE
+#endif
 
 /* Due to the fact that socket under Windows are not represented by
    standard file descriptors, we sometimes need to check whether a
@@ -248,6 +254,78 @@ static int fd_is_w32_socket(gint fd)
 #endif 
 }
 
+gint fd_connect_inet(gushort port)
+{
+	gint sock;
+	struct sockaddr_in addr;
+
+	sock = socket(AF_INET, SOCK_STREAM, 0);
+	if (!SOCKET_IS_VALID(sock)) {
+#ifdef G_OS_WIN32
+		debug_print("fd_connect_inet(): socket() failed: %d\n",
+			  WSAGetLastError());
+#else
+		perror("fd_connect_inet(): socket");
+#endif
+		return -1;
+	}
+
+	memset(&addr, 0, sizeof(addr));
+	addr.sin_family = AF_INET;
+	addr.sin_port = htons(port);
+	addr.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
+
+	if (connect(sock, (struct sockaddr *)&addr, sizeof(addr)) < 0) {
+		fd_close(sock);
+		return -1;
+	}
+
+	return sock;
+}
+gint fd_open_inet(gushort port)
+{
+	gint sock;
+	struct sockaddr_in addr;
+	gint val;
+
+	sock = socket(AF_INET, SOCK_STREAM, 0);
+	if (!SOCKET_IS_VALID(sock)) {
+#ifdef G_OS_WIN32
+		g_warning("fd_open_inet(): socket() failed: %d\n",
+			  WSAGetLastError());
+#else
+		perror("fd_open_inet(): socket");
+#endif
+		return -1;
+	}
+
+	val = 1;
+	if (setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, (char *)&val,
+		       sizeof(val)) < 0) {
+		perror("setsockopt");
+		fd_close(sock);
+		return -1;
+	}
+
+	memset(&addr, 0, sizeof(addr));
+	addr.sin_family = AF_INET;
+	addr.sin_port = htons(port);
+	addr.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
+
+	if (bind(sock, (struct sockaddr *)&addr, sizeof(addr)) < 0) {
+		perror("bind");
+		fd_close(sock);
+		return -1;
+	}
+
+	if (listen(sock, 1) < 0) {
+		perror("listen");
+		fd_close(sock);
+		return -1;
+	}
+
+	return sock;
+}
 
 gint fd_connect_unix(const gchar *path)
 {
@@ -395,24 +473,6 @@ static gboolean sock_check(GSource *source)
 	if (!sock || !sock->sock)
 		return FALSE;
 
-#if USE_OPENSSL
-	if (sock->ssl) {
-		if (condition & G_IO_IN) {
-			if (SSL_pending(sock->ssl) > 0)
-				return TRUE;
-			if (SSL_want_write(sock->ssl))
-				condition |= G_IO_OUT;
-		}
-
-		if (condition & G_IO_OUT) {
-			if (SSL_want_read(sock->ssl))
-				condition |= G_IO_IN;
-		}
-	}
-#elif USE_GNUTLS
-/* ?? */
-#endif
-
 	FD_ZERO(&fds);
 	FD_SET(sock->sock, &fds);
 
@@ -456,7 +516,7 @@ guint sock_add_watch(SockInfo *sock, GIOCondition condition, SockFunc func,
 	sock->condition = condition;
 	sock->data = data;
 
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 	if (sock->ssl)
 	{
 		GSource *source = g_source_new(&sock_watch_funcs,
@@ -1306,35 +1366,7 @@ static gint fd_read(gint fd, gchar *buf, gint len)
 	return read(fd, buf, len);
 }
 
-#if USE_OPENSSL
-static gint ssl_read(SSL *ssl, gchar *buf, gint len)
-{
-	gint err, ret;
-
-	if (SSL_pending(ssl) == 0) {
-		if (fd_check_io(SSL_get_rfd(ssl), G_IO_IN) < 0)
-			return -1;
-	}
-
-	ret = SSL_read(ssl, buf, len);
-
-	switch ((err = SSL_get_error(ssl, ret))) {
-	case SSL_ERROR_NONE:
-		return ret;
-	case SSL_ERROR_WANT_READ:
-	case SSL_ERROR_WANT_WRITE:
-		errno = EAGAIN;
-		return -1;
-	case SSL_ERROR_ZERO_RETURN:
-		return 0;
-	default:
-		g_warning("SSL_read() returned error %d, ret = %d\n", err, ret);
-		if (ret == 0)
-			return 0;
-		return -1;
-	}
-}
-#elif USE_GNUTLS
+#if USE_GNUTLS
 static gint ssl_read(gnutls_session ssl, gchar *buf, gint len)
 {
 	gint r;
@@ -1353,11 +1385,15 @@ static gint ssl_read(gnutls_session ssl, gchar *buf, gint len)
 		case 0: /* closed connection */
 			return -1;
 
+		case GNUTLS_E_REHANDSHAKE:
+			do {
+				r = gnutls_handshake(ssl);
+			} while (r == GNUTLS_E_AGAIN || r == GNUTLS_E_INTERRUPTED);
+			break; /* re-receive */
 		case GNUTLS_E_AGAIN:
 		case GNUTLS_E_INTERRUPTED:
 			errno = EAGAIN;
 			return -1;
-		break;
 
 		default:
 			return -1;
@@ -1373,7 +1409,7 @@ gint sock_read(SockInfo *sock, gchar *buf, gint len)
 
 	g_return_val_if_fail(sock != NULL, -1);
 
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 	if (sock->ssl)
 		ret = ssl_read(sock->ssl, buf, len);
 	else
@@ -1395,25 +1431,7 @@ gint fd_write(gint fd, const gchar *buf, gint len)
 	return write(fd, buf, len);
 }
 
-#if USE_OPENSSL
-static gint ssl_write(SSL *ssl, const gchar *buf, gint len)
-{
-	gint ret;
-
-	ret = SSL_write(ssl, buf, len);
-
-	switch (SSL_get_error(ssl, ret)) {
-	case SSL_ERROR_NONE:
-		return ret;
-	case SSL_ERROR_WANT_READ:
-	case SSL_ERROR_WANT_WRITE:
-		errno = EAGAIN;
-		return -1;
-	default:
-		return -1;
-	}
-}
-#elif USE_GNUTLS
+#if USE_GNUTLS
 static gint ssl_write(gnutls_session ssl, const gchar *buf, gint len)
 {
 	gint ret;
@@ -1443,7 +1461,7 @@ gint sock_write(SockInfo *sock, const gchar *buf, gint len)
 
 	g_return_val_if_fail(sock != NULL, -1);
 
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 	if (sock->ssl)
 		ret = ssl_write(sock->ssl, buf, len);
 	else
@@ -1482,12 +1500,8 @@ gint fd_write_all(gint fd, const gchar *buf, gint len)
 	return wrlen;
 }
 
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
-#if USE_OPENSSL
-static gint ssl_write_all(SSL *ssl, const gchar *buf, gint len)
-#else
+#ifdef USE_GNUTLS
 static gint ssl_write_all(gnutls_session ssl, const gchar *buf, gint len)
-#endif
 {
 	gint n, wrlen = 0;
 
@@ -1510,7 +1524,7 @@ gint sock_write_all(SockInfo *sock, const gchar *buf, gint len)
 
 	g_return_val_if_fail(sock != NULL, -1);
 
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 	if (sock->ssl)
 		ret = ssl_write_all(sock->ssl, buf, len);
 	else
@@ -1587,7 +1601,7 @@ gint sock_close(SockInfo *sock)
 	if (sock->sock_ch)
 		g_io_channel_unref(sock->sock_ch);
 
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 	if (sock->ssl)
 		ssl_done_socket(sock);
 	if (sock->g_source != 0)
