@@ -1210,6 +1210,7 @@ void matcherlist_free(MatcherList *cond)
 	for (l = cond->matchers ; l != NULL ; l = g_slist_next(l)) {
 		matcherprop_free((MatcherProp *) l->data);
 	}
+	g_slist_free(cond->matchers);
 	g_free(cond);
 }
 
@@ -2002,9 +2003,9 @@ static void add_str_default(gchar ** dest,
 
 /* matching_build_command() - preferably cmd should be unescaped */
 /*!
- *\brief	Build the command line to execute
+ *\brief	Build the command-line to execute
  *
- *\param	cmd String with command line specifiers
+ *\param	cmd String with command-line specifiers
  *\param	info Message info to use for command
  *
  *\return	gchar * Newly allocated string
