@@ -121,10 +121,6 @@ static PrefParam param_os_specific[] = {
 	 &prefs_common.pixmap_theme_path, P_STRING, NULL, NULL, NULL},
 
 	/* Other */
-	{"uri_open_command", NULL,
-	 &prefs_common.uri_cmd, P_STRING, NULL, NULL, NULL},
-	{"print_command", "notepad /p %s",
-	 &prefs_common.print_cmd, P_STRING, NULL, NULL, NULL},
 	{"ext_editor_command", "notepad %s",
 	 &prefs_common.ext_editor_cmd, P_STRING, NULL, NULL, NULL},
 
@@ -237,6 +233,8 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"linewrap_pastes", "TRUE", &prefs_common.linewrap_pastes, P_BOOL,
 	 NULL, NULL, NULL},
+	{"primary_paste_unselects", "FALSE", &prefs_common.primary_paste_unselects, P_BOOL,
+	 NULL, NULL, NULL},
 	{"linewrap_auto", "TRUE", &prefs_common.autowrap, P_BOOL,
 	 NULL, NULL, NULL},
 	{"auto_indent", "TRUE", &prefs_common.auto_indent, P_BOOL,
@@ -245,7 +243,7 @@ static PrefParam param[] = {
 	 P_BOOL, NULL, NULL, NULL},
         {"autosave_length", "50", &prefs_common.autosave_length, P_INT,
 	 NULL, NULL, NULL},
-#if USE_ENCHANT
+
 	{"enable_aspell", "TRUE", &prefs_common.enable_aspell, P_BOOL,
 	 NULL, NULL, NULL},
 	{"dictionary",  "", &prefs_common.dictionary, P_STRING,
@@ -262,7 +260,7 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"use_both_dicts", "FALSE", &prefs_common.use_both_dicts, P_BOOL,
 	 NULL, NULL, NULL},
-#endif
+
 	{"reply_with_quote", "TRUE", &prefs_common.reply_with_quote, P_BOOL,
 	 NULL, NULL, NULL},
 	{"compose_dnd_insert_or_attach", "0", &prefs_common.compose_dnd_mode, P_ENUM,
@@ -813,10 +811,12 @@ static PrefParam param[] = {
 	 P_INT, NULL, NULL, NULL},
 
 	/* Other */
+#ifndef G_OS_WIN32
 	{"uri_open_command", DEFAULT_BROWSER_CMD,
 	 &SPECIFIC_PREFS.uri_cmd, P_STRING, NULL, NULL, NULL},
 	{"print_command", "lpr %s",
 	 &SPECIFIC_PREFS.print_cmd, P_STRING, NULL, NULL, NULL},
+#endif
 	{"ext_editor_command", DEFAULT_EDITOR_CMD,
 	 &SPECIFIC_PREFS.ext_editor_cmd, P_STRING, NULL, NULL, NULL},
 	{"cmds_use_system_default", "FALSE",
@@ -1212,6 +1212,8 @@ void prefs_common_read_config(void)
 		prefs_common_read_history(SUMMARY_SEARCH_ADV_CONDITION_HISTORY);
 	prefs_common.message_search_history =
 		prefs_common_read_history(MESSAGE_SEARCH_HISTORY);
+	prefs_common.compose_save_to_history =
+		prefs_common_read_history(COMPOSE_SAVE_TO_HISTORY);
 
 	prefs_common.addressbook_custom_attributes = addressbook_update_custom_attr_from_prefs();
 
@@ -1308,6 +1310,8 @@ void prefs_common_write_config(void)
 		prefs_common.summary_search_adv_condition_history);
 	prefs_common_save_history(MESSAGE_SEARCH_HISTORY, 
 		prefs_common.message_search_history);
+	prefs_common_save_history(COMPOSE_SAVE_TO_HISTORY, 
+		prefs_common.compose_save_to_history);
 
 	prefs_common_save_history_to_dir(ADDRBOOK_DIR,
 		ADDRESSBOOK_CUSTOM_ATTRIBUTES, 
@@ -1518,6 +1522,9 @@ const gchar *prefs_common_translated_header_name(const gchar *header_name)
 
 const gchar *prefs_common_get_uri_cmd(void)
 {
+#ifdef G_OS_WIN32
+	return NULL;
+#else
 	gchar *tmp = NULL;
 	
 	if (!prefs_common.cmds_use_system_default)
@@ -1529,6 +1536,7 @@ const gchar *prefs_common_get_uri_cmd(void)
 	
 	g_free(tmp);
 	return "xdg-open %s";
+#endif
 }
 
 const gchar *prefs_common_get_ext_editor_cmd(void)
