@@ -995,7 +995,7 @@ void prefs_toolbar_init(void)
 	ToolbarPage *page;
 	static gchar *mainpath[3], *messagepath[3], *composepath[3];
 
-	mainpath[0] = _("Customize Toolbars");
+	mainpath[0] = _("Toolbars");
 	mainpath[1] = _("Main Window");
 	mainpath[2] = NULL;
 
@@ -1009,7 +1009,7 @@ void prefs_toolbar_init(void)
 	prefs_gtk_register_page((PrefsPage *) page);
 	prefs_toolbar_mainwindow = page;
 
-	messagepath[0] = _("Customize Toolbars");
+	messagepath[0] = _("Toolbars");
 	messagepath[1] = _("Message Window");
 	messagepath[2] = NULL;
 
@@ -1023,7 +1023,7 @@ void prefs_toolbar_init(void)
 	prefs_gtk_register_page((PrefsPage *) page);
 	prefs_toolbar_messageview = page;
 
-	composepath[0] = _("Customize Toolbars");
+	composepath[0] = _("Toolbars");
 	composepath[1] = _("Compose Window");
 	composepath[2] = NULL;
 
